"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_native_1 = require("react-native");
// Lib
const commands_1 = require("./lib/commands");
const errors_1 = require("./lib/errors");
class SimpelHoldWallet {
    constructor(callbackScheme) {
        this.callbackId = new Date().getTime();
        this.app = {
            name: "SimpleHold",
            scheme: "simplehold://",
        };
        this.resolvers = {};
        this.rejectors = {};
        this.callbackScheme = callbackScheme;
        this.start();
    }
    start() {
        react_native_1.Linking.addEventListener("url", this.handleOpenURL.bind(this));
    }
    cleanup() {
        react_native_1.Linking.removeEventListener("url", this.handleOpenURL.bind(this));
        this.resolvers = {};
    }
    installed() {
        const testUrl = this.app.scheme + commands_1.SimpleHoldCommand.getWallets;
        return react_native_1.Linking.canOpenURL(testUrl);
    }
    requestWallets() {
        const request = new commands_1.GetWalletsRequest(this.genId("wallets_"), this.callbackScheme);
        return this.sendRequest(request).then((result) => {
            return JSON.parse(result);
        });
    }
    genId(prefix) {
        this.callbackId++;
        return (prefix || "") + this.callbackId;
    }
    sendRequest(request) {
        return this.installed().then((result) => {
            return new Promise((resolve, reject) => {
                if (result) {
                    if (request.callbackScheme.length <= 0) {
                        request.callbackScheme = this.callbackScheme;
                    }
                    this.resolvers[request.id] = resolve;
                    this.rejectors[request.id] = reject;
                    react_native_1.Linking.openURL(commands_1.SimpleHoldCommand.getURL(request));
                }
                else {
                    reject({
                        error: errors_1.SimpleHoldError.notInstalled,
                        message: errors_1.SimpleHoldError.toString(errors_1.SimpleHoldError.notInstalled),
                    });
                }
            });
        });
    }
    handleOpenURL(event) {
        const response = commands_1.SimpleHoldCommand.parseURL(event.url);
        const resolver = this.resolvers[response.id];
        const rejector = this.rejectors[response.id];
        if (!resolver || !rejector) {
            return;
        }
        if (response.error !== errors_1.SimpleHoldError.none) {
            rejector({
                error: response.error,
                message: errors_1.SimpleHoldError.toString(response.error),
            });
        }
        else {
            resolver(response.result);
        }
        delete this.resolvers[response.id];
        delete this.rejectors[response.id];
    }
}
exports.default = SimpelHoldWallet;
