"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GetWalletsRequest = exports.SimpleHoldCommand = void 0;
const url_parse_1 = __importDefault(require("url-parse"));
const errors_1 = require("./errors");
var SimpleHoldCommand;
(function (SimpleHoldCommand) {
    SimpleHoldCommand["getWallets"] = "sdk_get_wallets";
})(SimpleHoldCommand = exports.SimpleHoldCommand || (exports.SimpleHoldCommand = {}));
(function (SimpleHoldCommand) {
    function parseURL(urlString) {
        const url = url_parse_1.default(urlString, "", true);
        const id = url.query.id || "";
        let error = "" + errors_1.SimpleHoldError.invalidResponse;
        let result = "";
        if (!id) {
            return { id, result, error };
        }
        error = url.query.error || errors_1.SimpleHoldError.none;
        if (id.startsWith("wallets_")) {
            result = url.query.wallets || "";
        }
        return { id, result, error };
    }
    SimpleHoldCommand.parseURL = parseURL;
    function getURL(request, scheme = "simplehold://") {
        let query = processQuery(request.toQuery());
        var msgUrl = url_parse_1.default(scheme + request.command + "?" + query);
        return msgUrl.toString();
    }
    SimpleHoldCommand.getURL = getURL;
    function processQuery(query) {
        return query
            .map((pair) => {
            return pair.k + "=" + pair.v;
        })
            .join("&");
    }
    SimpleHoldCommand.processQuery = processQuery;
})(SimpleHoldCommand = exports.SimpleHoldCommand || (exports.SimpleHoldCommand = {}));
class QueryItem {
    constructor(k, v) {
        this.k = k;
        this.v = v;
    }
}
class GetWalletsRequest {
    constructor(callbackId, callbackScheme, callbackPath) {
        this.command = SimpleHoldCommand.getWallets;
        this.callbackScheme = callbackScheme || "";
        this.callbackPath = callbackPath || SimpleHoldCommand.getWallets;
        this.id = callbackId;
    }
    toQuery() {
        var array = [];
        if (this.callbackScheme.length > 0) {
            array.push({ k: "app", v: this.callbackScheme });
            array.push({ k: "callback", v: this.callbackPath });
        }
        array.push({ k: "id", v: this.id });
        return array;
    }
}
exports.GetWalletsRequest = GetWalletsRequest;
